Welcome to py-stopwatch's documentation!
========================================

.. image:: https://img.shields.io/pypi/v/py-stopwatch?color=success
        :target: https://pypi.python.org/pypi/py_stopwatch

.. image:: https://readthedocs.org/projects/py-stopwatch/badge/?version=latest
        :target: https://py-stopwatch.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/py-stopwatch
        :target: https://pypi.python.org/pypi/py-stopwatch
        :alt: Python Version Support

.. image:: https://img.shields.io/github/issues/hrishikeshrt/py_stopwatch
        :target: https://github.com/hrishikeshrt/py_stopwatch/issues
        :alt: GitHub Issues

.. image:: https://img.shields.io/github/followers/hrishikeshrt?style=social
        :target: https://github.com/hrishikeshrt
        :alt: GitHub Followers

.. image:: https://img.shields.io/twitter/follow/hrishikeshrt?style=social
        :target: https://twitter.com/hrishikeshrt
        :alt: Twitter Followers


Stopwatch class for timing portions of python code.

* Free software: MIT license
* Documentation: https://py-stopwatch.readthedocs.io.


Features
========

* Tick-based stopwatch
* Support for Pause/Resume
* Support for multiple named-ticks
* Utility functions for time between different ticks
* No third party requirements.

.. include:: ../USAGE.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
